@@ -5,12 +5,12 @@
     <name>defaultlook</name>
     <message>
         <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="55"/>
-        <location filename="../defaultlook.cpp" line="467"/>
-        <location filename="../defaultlook.cpp" line="474"/>
-        <location filename="../defaultlook.cpp" line="491"/>
-        <location filename="../defaultlook.cpp" line="502"/>
-        <location filename="../defaultlook.cpp" line="512"/>
+        <location filename="../defaultlook.cpp" line="58"/>
+        <location filename="../defaultlook.cpp" line="527"/>
+        <location filename="../defaultlook.cpp" line="534"/>
+        <location filename="../defaultlook.cpp" line="551"/>
+        <location filename="../defaultlook.cpp" line="562"/>
+        <location filename="../defaultlook.cpp" line="572"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
@@ -143,9 +143,9 @@
     <message>
         <location filename="../defaultlook.ui" line="446"/>
         <location filename="../defaultlook.ui" line="549"/>
-        <location filename="../defaultlook.ui" line="741"/>
-        <location filename="../defaultlook.ui" line="860"/>
-        <location filename="../defaultlook.ui" line="902"/>
+        <location filename="../defaultlook.ui" line="740"/>
+        <location filename="../defaultlook.ui" line="894"/>
+        <location filename="../defaultlook.ui" line="936"/>
         <source>Apply</source>
         <translation>Применить</translation>
     </message>
@@ -177,16 +177,16 @@
     <message>
         <location filename="../defaultlook.ui" line="575"/>
         <source>Undo</source>
-        <translation>Отменить</translation>
+        <translation>Отмена</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="582"/>
         <source>Preview</source>
-        <translation>Предварительный просмотр</translation>
+        <translation>Предпросмотр</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
+        <source>Remove User Theme Set</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -196,198 +196,228 @@
     </message>
     <message>
         <location filename="../defaultlook.ui" line="614"/>
-        <location filename="../defaultlook.ui" line="707"/>
+        <location filename="../defaultlook.ui" line="760"/>
         <source>Compositor</source>
         <translation>Композитор</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="635"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настройки композитора Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="638"/>
-        <source>Xfwm Settings</source>
-        <translation>Настройки Xfmw</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="662"/>
-        <source>None</source>
-        <translation>Никакой</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="667"/>
-        <source>Xfwm (Xfce) Compositor</source>
-        <translation>Композитор Xfwm (Xfce)</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="672"/>
-        <source>Compton </source>
-        <translation>Compton</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="680"/>
-        <source>Edit compton.conf directly in text editor</source>
-        <translation>Редактировать compton.conf в текстовом редакторе</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="683"/>
-        <source>Edit compton.conf</source>
-        <translation>Редактировать compton.conf</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="714"/>
-        <source>Transparency and shadow options</source>
-        <translation>Параметры прозрачности и теней</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="721"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Запустить конфигуратор compton-conf</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="724"/>
+        <location filename="../defaultlook.ui" line="638"/>
         <source>Compton settings</source>
         <translation>Настройки Compton</translation>
     </message>
+    <message>
+        <location filename="../defaultlook.ui" line="662"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настройки композитора Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="665"/>
+        <source>Xfwm Settings</source>
+        <translation>Настройки Xfmw</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="689"/>
+        <source>None</source>
+        <translation>Никакой</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="694"/>
+        <source>Xfwm (Xfce) Compositor</source>
+        <translation>Композитор Xfwm (Xfce)</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="699"/>
+        <source>Compton </source>
+        <translation>Compton</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="707"/>
+        <source>Edit compton.conf directly in text editor</source>
+        <translation>Редактировать compton.conf в текстовом редакторе</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="710"/>
+        <source>Edit compton.conf</source>
+        <translation>Редактировать compton.conf</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="767"/>
+        <source>Transparency and shadow options</source>
+        <translation>Параметры прозрачности и теней</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="774"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../defaultlook.ui" line="777"/>
+        <source>VBlank</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="785"/>
+        <source>auto</source>
+        <translation>авторежим</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="790"/>
+        <source>glx</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="795"/>
+        <source>xpresent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="800"/>
+        <source>off</source>
+        <translation>выкл.</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="811"/>
         <source>Config Options</source>
         <translation>Опции конфигурации</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="785"/>
+        <location filename="../defaultlook.ui" line="819"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Сбросить Lightdm (экран логина) к системной теме по умолчанию</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="792"/>
+        <location filename="../defaultlook.ui" line="826"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation>Сбросить на предустановленные действия по правому клику в Thunar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="799"/>
+        <location filename="../defaultlook.ui" line="833"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation>Использовать драйвер intel вместо штатного &quot;modsetting&quot; драйвера (необходим перезапуск)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="806"/>
+        <location filename="../defaultlook.ui" line="840"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-intel.conf будет сохранен в домашней директории</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="813"/>
+        <location filename="../defaultlook.ui" line="847"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Использовать опцию amdgpu видео без тиринга</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="820"/>
+        <location filename="../defaultlook.ui" line="854"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-amd.conf будет скопирован в домашний каталог</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="827"/>
+        <location filename="../defaultlook.ui" line="861"/>
         <source>Use tearfree radeon driver option</source>
         <translation>Использовать опцию драйвера radeon видео без тиринга</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="834"/>
+        <location filename="../defaultlook.ui" line="868"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-radeon.conf будет скопирован в домашний каталог</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="874"/>
+        <location filename="../defaultlook.ui" line="908"/>
         <source>Other</source>
         <translation>Другое</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="882"/>
+        <location filename="../defaultlook.ui" line="916"/>
         <source>Enable single-click on desktop</source>
         <translation>Задействовать одиночный клик на рабочем столе</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="889"/>
+        <location filename="../defaultlook.ui" line="923"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Задействовать одиночный клик в Thunar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="926"/>
+        <location filename="../defaultlook.ui" line="960"/>
         <source>Show systray (notification area) frame</source>
         <translation>Отображать рамку systray (область уведомлений)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="933"/>
+        <location filename="../defaultlook.ui" line="967"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Показывать на панели окна со всех рабочих столов</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="940"/>
+        <location filename="../defaultlook.ui" line="974"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Включить монтирование внешних носителей для не-рут пользователей</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="947"/>
+        <location filename="../defaultlook.ui" line="981"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Отключить укорачивание длинных имен на рабочем столе</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="954"/>
+        <location filename="../defaultlook.ui" line="988"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Добавить hibernate в меню Выхода из системы</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="961"/>
+        <location filename="../defaultlook.ui" line="995"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>примечание: для hibernate необходим swap &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="466"/>
+        <location filename="../defaultlook.cpp" line="526"/>
         <source>About MX Tweak</source>
         <translation>О MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="467"/>
+        <location filename="../defaultlook.cpp" line="527"/>
         <source>Version: </source>
         <translation>Версия: </translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="468"/>
+        <location filename="../defaultlook.cpp" line="528"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Приложение для доводки штатного оформления и твиков</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="470"/>
+        <location filename="../defaultlook.cpp" line="530"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="471"/>
-        <location filename="../defaultlook.cpp" line="474"/>
+        <location filename="../defaultlook.cpp" line="531"/>
+        <location filename="../defaultlook.cpp" line="534"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="472"/>
+        <location filename="../defaultlook.cpp" line="532"/>
         <source>Cancel</source>
         <translation>Отменить</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="503"/>
+        <location filename="../defaultlook.cpp" line="563"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Готово! Может потребоваться перезапуск Firefox</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="513"/>
+        <location filename="../defaultlook.cpp" line="573"/>
         <source>This app is Xfce-only</source>
         <translation>Приложение только для Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="655"/>
+        <location filename="../defaultlook.cpp" line="715"/>
         <source>Panel settings</source>
         <translation>Настройки панели</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="656"/>
+        <location filename="../defaultlook.cpp" line="716"/>
         <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -396,7 +426,7 @@
         <translation type="vanished">Текущие настройки панели были сохранены в скрытой папке .restore вашего домашнего каталога (~/.restore/)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="1073"/>
+        <location filename="../defaultlook.cpp" line="1160"/>
         <source>Choose a theme set</source>
         <translation>Выберите набор темы</translation>
     </message>
@@ -413,8 +443,8 @@
     <name>theming_to_tweak</name>
     <message>
         <location filename="../theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
-        <translation>Диалоговое окно</translation>
+        <source>New Theme Set</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../theming_to_tweak.ui" line="20"/>
@@ -426,7 +456,7 @@
     <name>window_buttons</name>
     <message>
         <location filename="../window_buttons.ui" line="14"/>
-        <location filename="../window_buttons.cpp" line="36"/>
+        <location filename="../window_buttons.cpp" line="37"/>
         <source>Window Buttons</source>
         <translation>Кнопки окон</translation>
     </message>
@@ -639,7 +669,7 @@
         <translation>Закрыть</translation>
     </message>
     <message>
-        <location filename="../xfwm_compositor_settings.cpp" line="38"/>
+        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
         <source>Xfwm Compositor Settings</source>
         <translation>Настройки композитора Xfwm</translation>
     </message>
